@@ -13,6 +13,7 @@
 from .auth import Auth
 from .storage import Storage
 from .database import Database
+from .firestore import Firestore
 from ._custom_requests import _custom_request
 from ._service_account_credentials import _service_account_creds_from_secret
 
@@ -43,6 +44,7 @@ class Firebase:
 		self.api_key = config["apiKey"]
 		self.auth_domain = config["authDomain"]
 		self.database_url = config["databaseURL"]
+		self.project_id = config["projectId"]
 		self.storage_bucket = config["storageBucket"]
 
 		self.credentials = None
@@ -77,6 +79,16 @@ class Firebase:
 
 		return Database(self.credentials, self.database_url, self.requests)
 
+	def firestore(self):
+		"""Initializes and returns a new Firebase Cloud Firestore
+		instance.
+
+		:return: A newly initialized instance of Firestore.
+		:rtype: Firestore
+		"""
+
+		return Firestore(self.api_key, self.credentials, self.project_id, self.requests)
+
 	def storage(self):
 		"""Initializes and returns a new Firebase Storage instance.
 
